+++
title = "Menu Title property"
tags = ["menu", "title"]
draft = false
[menu.test]
  weight = 3003
  identifier = "menu-title-property"
  title = "Page title for menu"
+++

The `title` property for menu entries was introduced in Hugo v0.32 in
[this commit](https://github.com/gohugoio/hugo/commit/9df3736fec164c51d819797416dc263f2869be77).
